import { AlphaFilter } from 'pixijs/filter/alpha';
import { BlurFilter, BlurFilterPass } from 'pixijs/filter/blur';
import { ColorMatrixFilter } from 'pixijs/filter/color-matrix';
import { DisplacementFilter } from 'pixijs/filter/displacement';
import { FXAAFilter } from 'pixijs/filter/fxaa';
import { NoiseFilter } from 'pixijs/filter/noise';
import 'pixijs/display/cache-as-bitmap';
import 'pixijs/display/get-child-by-name';
import 'pixijs/display/get-global-position';
/**
 * This namespace contains WebGL-only display filters that can be applied
 * to DisplayObjects using the {@link PIXI.DisplayObject#filters filters} property.
 *
 * Since PixiJS only had a handful of built-in filters, additional filters
 * can be downloaded {@link https://github.com/pixijs/pixi-filters here} from the
 * PixiJS Filters repository.
 *
 * All filters must extend {@link PIXI.Filter}.
 * @example
 * import { Application, Graphics, filters } from 'pixijs/browser';
 *
 * // Create a new application
 * const app = new Application();
 *
 * // Draw a green rectangle
 * const rect = new Graphics()
 *     .beginFill(0x00ff00)
 *     .drawRect(40, 40, 200, 200);
 *
 * // Add a blur filter
 * rect.filters = [new filters.BlurFilter()];
 *
 * // Display rectangle
 * app.stage.addChild(rect);
 * document.body.appendChild(app.view);
 * @namespace PIXI.filters
 */
export declare const filters: {
    AlphaFilter: typeof AlphaFilter;
    BlurFilter: typeof BlurFilter;
    BlurFilterPass: typeof BlurFilterPass;
    ColorMatrixFilter: typeof ColorMatrixFilter;
    DisplacementFilter: typeof DisplacementFilter;
    FXAAFilter: typeof FXAAFilter;
    NoiseFilter: typeof NoiseFilter;
};
export * from 'pixijs/accessibility';
export * from 'pixijs/app';
export * from 'pixijs/assets';
export * from 'pixijs/compressed-textures';
export * from 'pixijs/core';
export * from 'pixijs/display';
export * from 'pixijs/events';
export * from 'pixijs/extract';
export * from 'pixijs/graphics';
export * from 'pixijs/mesh';
export * from 'pixijs/mesh/extras';
export * from 'pixijs/particle-container';
export * from 'pixijs/prepare';
export * from 'pixijs/sprite';
export * from 'pixijs/spritesheet';
export * from 'pixijs/sprite-animated';
export * from 'pixijs/sprite-tiling';
export * from 'pixijs/text';
export * from 'pixijs/text-bitmap';
